extern struct Color White, Black, Red, DarkRed, Green, Blue, LightGray, Gray, DarkGray;


extern void DrawLine(int x1pos, int y1pos, int x2pos, int y2pos,
                     Color *LineColor);
extern void DrawPoint(int xpos, int ypos, Color *PointColor);
extern void DrawPoint(struct Point *Position, Color *PointColor);
extern void DrawPoint(struct Point *Position, Color *PointColor, float Offset, int Type);
extern int DrawText(int xpos, int ypos, char *text,
                    Color *TextColor, int big=0);
extern void DrawRect(int x1pos, int y1pos, int x2pos, int y2pos,
                     int x3pos, int y3pos, int x4pos, int y4pos,
                     Color *LineColor);
extern void DrawCircle(int xpos, int ypos, struct Color *CircleColor,
                       int numPoints, float Size, int offset);
extern void DrawCircle(Object *Obj, struct Color *CircleColor,
                       float Transparency, int numPoints, float Size);
extern void DrawPowerup(Object *Obj);
extern void DrawObject(Object *Obj);
extern void CalcPosition(struct Point *Position, struct Point *newPosition);
extern void CalcPoint(struct Point *point, struct Point *newpoint);
extern void CalcPointWithRotation(struct Point *point);
extern void InitScreen();
extern void StartGame();
extern void ClearScreen();
extern void Setup3dMode();
extern void UpdateScreen();
extern void InitColors();
extern void InitTransparencyQueue();
extern void QueueTransparency(struct Point *Position, int objectnum, int Type);
extern void DrawTransparencies();
extern void DrawCrosshairs();
extern void LoadTexture(char *fn);
extern void EnableTransparency();
extern void DisableTransparency();
extern void InitMatrixMode();
extern void SetupGameMatrixMode();
extern void DrawTest();
